==> hajee-connect-0.0.3.tar.gz: hajee-connect-0.0.3/lib/connect/interpolator.rb <==
module Connect
  ##
  #
  # This class implements the string interpolator. The string is scanned for values to be interpolated.
  # If they are found, they are replaced with the current values.
  #
  class Interpolator
    #
    # The format of a value that needs to be interpolated
    #
    CONNECT_REGEXP = /(\$\{\s*(?:[a-zA-Z][a-zA-Z0-9_]*::)*[a-zA-Z][a-zA-Z0-9_\.\:\&\[\]\'\(\),]*\s*\})/
    PUPPET_REGEXP = /(\%\{\s*(?:::)?(?:[a-zA-Z][a-zA-Z0-9_]::)*[a-zA-Z][a-zA-Z0-9_]*\s*\})/

    def initialize(resolver)
      @resolver = resolver
    end

    ##
    #
    # Look for elements to interpolate and replace them with the actual values
    #
    # @param string [String] the string to be interpolated
    #
    def translate(string)
      string = interpolate_connect_variables(string)
      interpolate_puppet_variables(string)
    end

    private

    def interpolate_connect_variables(string)
      variable_strings = string.scan(CONNECT_REGEXP).flatten
      variable_names   = variable_strings.map { |n| n.split(/\{|\}/).last.gsub(/\s+/, '') }
      variable_values  = variable_names.map { |n| connect_interpolate(n) }
      variable_strings.each_index do |index|
        string.gsub!(variable_strings[index], variable_values[index])
      end
      string
    end

    def interpolate_puppet_variables(string)
      variable_strings = string.scan(PUPPET_REGEXP).flatten
      variable_names   = variable_strings.map { |n| n.split(/\{|\}/).last.gsub(/\s+/, '') }
      variable_values  = variable_names.map { |n| puppet_interpolate(n) }
      variable_strings.each_index do |index|
        string.gsub!(variable_strings[index], variable_values[index])
      end
      string
    end

    private

    def connect_interpolate(variable)
      variable, selector = variable.split(/([\[\.].*)/)
      value = @resolver.lookup_value(variable)
      Selector.run(value, selector).to_s
    end

    def puppet_interpolate(variable)
      if Connect::Dsl.config.scope.nil?
        ''
      else
        Connect::Dsl.config.scope[variable].to_s
      end
    end
  end
end

==> hajee-connect-0.0.24.tar.gz: hajee-connect-0.0.24/lib/connect/interpolator.rb <==
module Connect
  ##
  #
  # This class implements the string interpolator. The string is scanned for values to be interpolated.
  # If they are found, they are replaced with the current values.
  #
  class Interpolator
    #
    # The format of a value that needs to be interpolated
    #
    CONNECT_REGEXP = /(\$\{\s*(?:[a-zA-Z][a-zA-Z0-9_]*::)*[a-zA-Z][a-zA-Z0-9_\.\:\&\[\]\'\(\),]*\s*\})/
    PUPPET_REGEXP = /(\%\{\s*(?:::)?(?:[a-zA-Z][a-zA-Z0-9_]::)*[a-zA-Z][a-zA-Z0-9_]*\s*\})/

    def initialize(resolver)
      @resolver = resolver
    end

    ##
    #
    # Look for elements to interpolate and replace them with the actual values
    #
    # @param string [String] the string to be interpolated
    #
    def translate(string, xref = nil)
      string = interpolate_connect_variables(string, xref)
      interpolate_puppet_variables(string)
    end

    ##
    #
    # Return true if the string contains interpolation
    #
    # @param string [String] the string to be interpolated
    #
    def contains_interpolation?(string)
      contains_connect_variables?(string) || contains_puppet_variables?(string)
    end

    private

    def contains_connect_variables?(string)
      string.scan(CONNECT_REGEXP).flatten != []
    end

    def contains_puppet_variables?(string)
      string.scan(PUPPET_REGEXP).flatten != []
    end

    def interpolate_connect_variables(string, xref)
      variable_strings = string.scan(CONNECT_REGEXP).flatten
      variable_names   = variable_strings.map { |n| n.split(/\{|\}/).last.gsub(/\s+/, '') }
      variable_values  = variable_names.map { |n| connect_interpolate(n, xref) }
      variable_strings.each_index do |index|
        string.gsub!(variable_strings[index], variable_values[index])
      end
      string
    end

    def interpolate_puppet_variables(string)
      variable_strings = string.scan(PUPPET_REGEXP).flatten
      variable_names   = variable_strings.map { |n| n.split(/\{|\}/).last.gsub(/\s+/, '') }
      variable_values  = variable_names.map { |n| puppet_interpolate(n) }
      variable_strings.each_index do |index|
        string.gsub!(variable_strings[index], variable_values[index])
      end
      string
    end

    def connect_interpolate(variable, xref)
      variable, selector = variable.split(/([\[\.].*)/)
      value = @resolver.lookup(variable)
      @resolver.register_reference(variable, xref)
      Selector.run(value, selector).to_s
    end

    def puppet_interpolate(variable)
      if Connect::Dsl.config.scope.nil?
        ''
      else
        Connect::Dsl.config.scope[variable].to_s
      end
    end
  end
end
